<?php

namespace Drupal\azure_login\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Defines a form that configures forms module settings.
 */
class SiteConfigurationForm extends ConfigFormBase {

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Constructs a new SiteConfiguration Form.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LanguageManagerInterface $language_manager, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($config_factory);

    $this->languageManager = $language_manager;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('language_manager'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'azure_login_site_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'azure_login.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('azure_login_site_settings.settings');
    
    if (!empty($config->get('cilentId'))) {
        $cilentId = substr($config->get('cilentId'), -4);
        $cilentId = "-----------------------------" . $cilentId;
    }
    else {
        $cilentId = "";
    }
    $form['cilentId'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Application (client) ID'),
      '#description' => $this->t('Enter a Application (client) ID. For ex. 7cacbe9f-a562-4841-9c0e-42617785fae3'),
      '#default_value' => $cilentId,
    ];
    if (!empty($config->get('tenantID'))) {
        $tenantID = substr($config->get('tenantID'), -4);
        $tenantID = "-----------------------------" . $tenantID;
    }
    else {
        $tenantID = "";
    }
    $form['tenantID'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Directory (tenant) ID'),
      '#description' => $this->t('Enter a Directory (tenant) ID. For ex. b01c4e5e-95f9-4bb2-9f18-2469e29f5146'),
      '#default_value' => $tenantID,
    ];
    
    if (!empty($config->get('clientSecret'))) {
        $clientSecret = substr($config->get('clientSecret'), -4);
        $clientSecret = "-----------------------------" . $clientSecret;
    }
    else {
        $clientSecret = "";
    }
    $form['clientSecret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Secret Value'),
      '#description' => "Enter a Secret Value. For ex. j1P8Q~1T123cl_byTqNbLozVfrtdrvdfs6M8N7.Ybb~f",
      '#default_value' => $clientSecret,
    ];
    
    if (!empty($config->get('redirectUrl'))) {
        $redirectUrl = substr($config->get('redirectUrl'), -4);
        $redirectUrl = "-----------------------------" . $redirectUrl;
    }
    else {
        $redirectUrl = "";
    }
    $form['redirectUrl'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Redirect URL'),
      '#default_value' => $redirectUrl,
    ];
    
    if (!empty($config->get('default_password'))) {
        $default_password = substr($config->get('default_password'), -4);
        $default_password = "-----------------------------" . $default_password;
    }
    else {
        $default_password = "";
    }
    $form['default_password'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Password'),
      '#default_value' => $default_password,
    ];
    
    if (!empty($config->get('group_id'))) {
        $group_id = substr($config->get('group_id'), -4);
        $group_id = "-----------------------------" . $group_id;
    }
    else {
        $group_id = "";
    }
    
    $form['group_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Group ID'),
      '#default_value' => $group_id,
      '#description' => "Enter a Group ID. For ex. ff3cc60f-79bd-4766-b530-d1da86e373c0"
    ];
    
    $form_state->setCached(FALSE);

    return parent::buildForm($form, $form_state); 
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::getContainer()->get('config.factory')->getEditable('azure_login_site_settings.settings');
    //$this->config('azure_login_site_settings.settings')
      $config->set('cilentId', $form_state->getValue('cilentId'));
      if (!empty($form_state->getValue('clientSecret'))) {
        $config->set('clientSecret', $form_state->getValue('clientSecret'));
      }
      $config->set('redirectUrl', $form_state->getValue('redirectUrl'));
      $config->set('tenantID', $form_state->getValue('tenantID'));
      $config->set('default_password', $form_state->getValue('default_password'));
      $config->set('group_id', $form_state->getValue('group_id'));
      $config->save();
    parent::submitForm($form, $form_state);
  }

}
